mysql.exceptions.server.Missing_Skip_Slave

Package mysql :: Package exceptions :: Module server :: Class Missing_Skip_Slave |
[hide private]
[frames] | no frames]

# Class Missing_Skip_Slave

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  Missing_Skip_Slave

It is recommended to use --skip-slave-start when doing step-by-step replication with START SLAVE UNTIL; otherwise, you will get problems if you get an unexpected slave's mysqld restart

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`